from classes.field import Field
from classes.name import Name
from classes.birthday import Birthday
from classes.phone import Phone
from classes.email import Email
from classes.address import Address
from classes.record import Record
from classes.addressbook import AddressBook

from classes.note import Note
from classes.notes import Notes
from classes.functions import make_menu

from sort import sort
from terminal_bot_records_notes import

from classes.settings import filename, PAG, notes_filename


__autor__ = 'Avtarso'
__version__ = '0.0.1'
__email__ = 't0676352927@gmail.com'
